translate.storage.oo.oofile

Package translate :: Package storage :: Module oo :: Class oofile |
[hide private]
[frames] | no frames]

# Class oofile

source code

this represents an entire .oo file

Nested Classes | [hide private]
| UnitClass this represents a number of translations of a resource

Instance Methods | [hide private]
__init__(self, input=None) constructs the oofile | source code
addline(self, thisline) adds a parsed line to the file | source code
parse(self, input) parses lines and adds them to the file | source code
__str__(self) convert to a string. | source code
getoutput(self) converts all the lines back to tab-delimited form | source code

Method Details | [hide private]

### __str__(self) (Informal representation operator) | source code
convert to a string. double check that unicode is handled